@@ -6,7 +6,7 @@ Classes in this module are heavily inspired by the
 from __future__ import annotations
 from dataclasses import dataclass
 from inspect import isclass, iscoroutinefunction
-from typing import get_type_hints, Any, Callable, Dict, Optional, Tuple
+from typing import get_type_hints, Any, Callable, Dict, Optional, Tuple, Type
 
 
 @dataclass(frozen=True)
@@ -20,9 +20,21 @@ class SpyCall:
     """
 
     spy_id: int
+    spy_name: str
     args: Tuple[Any, ...]
     kwargs: Dict[str, Any]
 
+    def __str__(self) -> str:
+        """Stringify the call to something human readable.
+
+        `SpyCall(spy_id=42, spy_name="name", args=(1,), kwargs={"foo": False})`
+        would stringify as `"name(1, foo=False)"`
+        """
+        args_list = [repr(arg) for arg in self.args]
+        kwargs_list = [f"{key}={repr(val)}" for key, val in self.kwargs.items()]
+
+        return f"{self.spy_name}({', '.join(args_list + kwargs_list)})"
+
 
 CallHandler = Callable[[SpyCall], Any]
 
@@ -34,8 +46,14 @@ class BaseSpy:
     - Lazily constructs child spies when an attribute is accessed
     """
 
-    def __init__(self, handle_call: CallHandler, spec: Optional[Any] = None) -> None:
+    def __init__(
+        self,
+        handle_call: CallHandler,
+        spec: Optional[Any] = None,
+        name: Optional[str] = None,
+    ) -> None:
         """Initialize a BaseSpy from a call handler and an optional spec object."""
+        self._name = name or (spec.__name__ if spec is not None else "spy")
         self._spec = spec
         self._handle_call: CallHandler = handle_call
         self._spy_children: Dict[str, BaseSpy] = {}
@@ -73,6 +91,7 @@ class BaseSpy:
         spy = create_spy(
             handle_call=self._handle_call,
             spec=child_spec,
+            name=f"{self._name}.{name}",
         )
 
         self._spy_children[name] = spy
@@ -85,28 +104,31 @@ class Spy(BaseSpy):
 
     def __call__(self, *args: Any, **kwargs: Any) -> Any:
         """Handle a call to the spy."""
-        return self._handle_call(SpyCall(id(self), args, kwargs))
+        return self._handle_call(SpyCall(id(self), self._name, args, kwargs))
 
 
-class AsyncSpy(Spy):
+class AsyncSpy(BaseSpy):
     """An object that records all async. calls made to itself and its children."""
 
     async def __call__(self, *args: Any, **kwargs: Any) -> Any:
         """Handle a call to the spy asynchronously."""
-        return self._handle_call(SpyCall(id(self), args, kwargs))
+        return self._handle_call(SpyCall(id(self), self._name, args, kwargs))
 
 
 def create_spy(
     handle_call: CallHandler,
     spec: Optional[Any] = None,
     is_async: bool = False,
+    name: Optional[str] = None,
 ) -> Any:
     """Create a Spy from a spec.
 
     Functions and classes passed to `spec` will be inspected (and have any type
     annotations inspected) to ensure `AsyncSpy`'s are returned where necessary.
     """
-    if iscoroutinefunction(spec) or is_async is True:
-        return AsyncSpy(handle_call)
+    _SpyCls: Type[BaseSpy] = Spy
 
-    return Spy(handle_call=handle_call, spec=spec)
+    if iscoroutinefunction(spec) or is_async is True:
+        _SpyCls = AsyncSpy
+
+    return _SpyCls(handle_call=handle_call, spec=spec, name=name)
